@@ -120,7 +120,7 @@ def clean(number, deletechars=''):
         number = ''.join(x for x in number)
     except Exception:
         raise InvalidFormat()
-    if sys.version < '3' and isinstance(number, str):  # pragma: no cover (Python 2/3 specific code)
+    if sys.version < '3' and isinstance(number, str):  # pragma: no cover (Python 2 specific code)
         try:
             number = _clean_chars(number.decode()).encode()
         except UnicodeError:
@@ -128,7 +128,7 @@ def clean(number, deletechars=''):
                 number = _clean_chars(number.decode('utf-8')).encode('utf-8')
             except UnicodeError:
                 pass
-    else:  # pragma: no cover (Python 2/3 specific code)
+    else:  # pragma: no cover (Python 3 specific code)
         number = _clean_chars(number)
     return ''.join(x for x in number if x not in deletechars)
 
@@ -137,9 +137,8 @@ def get_number_modules(base='stdnum'):
     """Yield all the module and package names under the specified module."""
     __import__(base)
     module = sys.modules[base]
-    for loader, name, is_pkg in pkgutil.walk_packages(
-            module.__path__, module.__name__ + '.',
-            onerror=lambda x: None):
+    for _loader, name, _is_pkg in pkgutil.walk_packages(
+            module.__path__, module.__name__ + '.'):
         __import__(name)
         module = sys.modules[name]
         if hasattr(module, 'validate'):
@@ -158,14 +157,6 @@ def get_module_description(module):
     return _strip_doctest_re.sub('', doc).strip()
 
 
-def get_module_list():
-    for module in get_number_modules():
-        yield ' * %s: %s' % (
-            module.__name__.replace('stdnum.', ''),
-            get_module_name(module),
-        )
-
-
 def get_cc_module(cc, name):
     """Find the country-specific named module."""
     cc = cc.lower()
